.. currentmodule:: sardana.pool.pooldefs

:mod:`~sardana.pool.pooldefs`
=============================

.. automodule:: sardana.pool.pooldefs

.. rubric:: Constants

.. autodata:: sardana.pool.pooldefs.ControllerAPI



